import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Tweakable code that can change to accommodate the dataset
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'arun-thotakuri/', // User
  '4cfeeb36976ec98561685576680c3465/', // Id of the Gist
  'raw/ef9e6f6ada4185e3b39c1d70e433bc35e591fe28/', // commit
  'diabetes.csv', // File name
].join('');

const parseRow = (d) => {
  d.Pregnancies = +d.Pregnancies;
  d.Glucose = +d.Glucose;
  d.BloodPressure = +d.BloodPressure;
  d.SkinThickness = +d.SkinThickness;

  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Generic code for rendering, shouldn't include any hard coded numbers
const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.BMI) // Change to match your dataset
    .yValue((d) => d.Glucose) // Change to match your dataset
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);
  svg.call(plot);

  const columns = [
    'Pregnancies',
    'Glucose',
    'BloodPressure',
    'SkinThickness',
    'Insulin',
    'BMI',
    'DiabetesPedigreeFunction',
    'Age',
  ];
  let i = 0;
  setInterval(() => {
    const column = columns[i % columns.length];
    plot.xValue((d) => d[column]);
    svg.call(plot);
    i++;
  }, 2000);
};

main();
